// This file contains utility-functions for the DUVA web-application for data-acquisition
// (c) DUVA-Anwendergemeinschaft
// Version: 4.11.3.3
// last change: 29.02.2016
//

var 
  nl = '\n';
  auto = false;
  notified = false;
  saved = false;
  evalRules = true;
  rules = 0;
  lastType = '';
  lastName = '';
  lastField = null;
  lastParam1 = null;
  lastParam2 = null;
  lastParam3 = null;
  lastParam4 = null;
  nextField = null;
  autoPaging = true;
  propagating = new Object();

function getKey(keyEvent)
{
  var lastKey;

  if (keyEvent)
    lastKey = keyEvent.which;
  else
    lastKey = event.keyCode;
  
  if (lastKey == 13)
  {
    if (checkField(true)) gotoField(nextField);
    return false;
  }
  
  if (lastKey == 27)
  {
    evalRules = false;
    alert(messages[301]);
    return false;
  }
  
  auto = (lastKey != 9) && (lastKey != 13) && (lastKey < 35 || lastKey > 40);
  notified = false;
}

function isInt(s)
{
  c = s.charCodeAt(0);
  if ((c < 48 && c != 43 && c != 45) || c > 57)
    return false;
  for (i=1;i<s.length;i++)
  {
    c = s.charCodeAt(i);
    if (c < 48 || c > 57)
      return false;
  }

  return true;
}

function stringToInt(s)
{
  while(s.slice(0, 1) == '0') 
    s = s.slice(1);
  if (s == '')
    return 0;
  else if (isInt(s))
    return parseInt(s);
  else
    return Number.NaN;
}

function getExtension(filename)
{
  var pos = filename.lastIndexOf('.');
  if (pos >= 0)
    return filename.substr(pos).toLowerCase();
  else
    return '';
}

function isChecked(radioButton)
{
  if (radioButton.length)
    for (i=0; i<radioButton.length; i++)
    {
      if (radioButton[i].checked)
        return true;
    }
  else
    if (radioButton.checked)
      return true;
  
  return false;
}

function autoReturn(field, length)
{
  return (auto && !notified && field.value.length == length);
}

function textLimit(field, limit)
{
  var msg;

  if (field.value.length > limit)
  {
    field.value = field.value.substr(0, limit);
    msg = messages[110].replace(/#LIMIT/, String(limit));
    show(messages[0] + nl + msg);
  }
}

function listChanged(inputField, listField)
{
  changeList(listField);
  if (listField.value == '\b')
    inputField.value = '';
  else
    inputField.value = listField.value;
}

function listValueActive(list, value)
{
  for (var i=0; i<list.length; i++)
    if ((list.options[i].value == value) && (list.options[i].disabled))
      return false;

  return true;
}

function listInputChanged(inputField, listField, length, flag, next)
{
  if (auto && !notified && inputField.value.length == length)
  {
    if (listValueActive(listField, inputField.value))
      listField.value = inputField.value;
    if (listField.value != inputField.value)
      show(messages[0] + nl + messages[105]);
    else
    {
      listField.onchange();
      if (flag) 
        gotoField(next);
    }
  }
}

function addLits(value, mask)
{
  var litValue = '';

  if (value != '')
    for (i=0,j=0; i<mask.length; i++)
      if (mask.charAt(i) != '\b')
        litValue += mask.charAt(i); 
      else
        if (j < value.length)
          litValue += value.charAt(j++); 
   
  return litValue;
}

function delLits(value, mask)
{
  var litValue = '';
  
  for (i=0; i<value.length; i++)
    if (mask.charAt(i) == '\b')
      litValue += value.charAt(i); 

  return litValue;
}

function checkFormat(field, format)
{
  var OptChar = '-';
  var OblChar = '+';
  var LitChar = '|';
  var typeMask = "";
  var charMask = "";
  var value = field.value;
  var inputError;
  var valueLen;
  var valueIndex;
  var maskLen;
  var maskIndex;

  function getMasks()
  {
    var len = format.length;
    var index = 0;
 
    while (index < len)
    {
      switch (format.charAt(index)) 
      {
        case '0':
        case 'A':
        case 'C':
        case 'D':
        case 'J':
        case 'L':
        case 'M':
        case 'T':
        case 'Y':
          typeMask += OblChar;
	break;

        case '9':
        case 'a':
        case 'c':
        case 'l':
          typeMask += OptChar;
        break;
        
        case '\\':
          typeMask += LitChar;
          index++;
        break;
        
	default:
          typeMask += LitChar;
      }
      if (index < len)
        charMask += format.charAt(index);
      index++;
    }
  }

  function validate()
  {
    function isNum(c)
    {
      return (c >= '0') && (c <= '9');
    }
    
    function isUml(c)
    {
      return (c == '') || (c == '') || (c == '') || (c == '') || (c == '') || (c == '') || (c == '');
    }
    
    function isAlpha(c)
    {
      return ((c >= 'A') && (c <= 'Z')) || ((c >= 'a') && (c <= 'z')) || isUml(c);
    }
    
    function isAlphaNum(c)
    {
      return isAlpha(c) || isNum(c);
    }
    
    switch (charMask.charAt(maskIndex))
    {
      case '0':
      case 'D':
      case 'J':
      case 'M':
      case 'T':
      case 'Y':
        return isNum(value.charAt(valueIndex));
      case '9':
        return isNum(value.charAt(valueIndex)) || (value.charAt(valueIndex) == ' ');
      case 'A':
        return isAlphaNum(value.charAt(valueIndex));
      case 'a':
        return isAlphaNum(value.charAt(valueIndex)) || (value.charAt(valueIndex) == ' ');
      case 'L':
        return isAlpha(value.charAt(valueIndex));
      case 'l':
        return isAlpha(value.charAt(valueIndex)) || (value.charAt(valueIndex) == ' ');
      default:
        return true;
    }
  }

  function expandValue()
  {
    if (valueLen < maskLen)
      for (i=maskIndex-1; i>=0; i--) 
        if ((typeMask.charAt(i) == OptChar) && (value.charAt(i) != ' '))
        {
          value = value.slice(0, i) + ' ' + value.slice(i, value.length);
          return true;
        }
      
    return false;
  }

  getMasks();
  maskLen = typeMask.length;
  do {
    inputError = false;
    valueLen = value.length;
    valueIndex = 0;
    maskIndex = 0;
    while (!inputError && maskIndex < maskLen)
    {
      switch (typeMask.charAt(maskIndex))
      {
        case OblChar:
          inputError = !validate();
        break;
        case OptChar:
          if (!validate())
            if (valueLen < maskLen)
              value = value.slice(0, valueIndex) + ' ' + value.slice(valueIndex, value.length);
            else
              inputError = true;
        break;
        case LitChar:
          if (value.charAt(valueIndex) != charMask.charAt(maskIndex))
            if (valueLen < maskLen)
              value = value.slice(0, valueIndex) + charMask.charAt(maskIndex) + value.slice(valueIndex, value.length);
            else
              inputError = true;
      }
      valueIndex++;
      maskIndex++;
    }
  } while (inputError && expandValue());
  for (i=valueLen; i<maskLen; i++)
    value += ' ';
  if (!inputError)
     field.value = value;

  return !inputError;
}

function checkIdent(field, name, obligatory, format, flag, next)
{
  var error = 0;
  if (obligatory && field.value == '')
    error = 100;
  else if(format && format != '' && field.value != '' && !checkFormat(field, format))
    error = 111;
  
  if (error)
  {
    show(messages[0] + nl + name + nl + messages[error] + nl + format);
    field.select();
    field.focus();
    return false;
  } else {
    if (flag)
      gotoField(next);
    return true;
  }
}

function checkDate(field, name, obligatory, format, flag, next)
{
  var error = 0;
  var pos, year, month, day;
  
  if (obligatory && field.value == '')
    error = 100;
  else if (field.value != '')
    if (!checkFormat(field, format))
      error = 111;
    else
    {
      pos = Math.max(format.indexOf('JJJJ'), format.indexOf('YYYY'));
      if (pos < 0)
      {
        pos = Math.max(format.indexOf('JJ'), format.indexOf('YY'));
        if (pos >= 0)
          year = stringToInt(field.value.substr(pos, 2));
        else
          year = 0;
      } else year = stringToInt(field.value.substr(pos, 4));
      if (isNaN(year))
        error = 101;                                       // illegal value for year
      else
      {
        pos = format.indexOf('MM');
        if (pos >= 0)
        {
          month = stringToInt(field.value.substr(pos, 2));
          if (isNaN(month) || month < 1 || month > 12)
            error = 102;                                   // illegal value for month
          else
          {
            pos = Math.max(format.indexOf('TT'), format.indexOf('DD'));
            if (pos >= 0)
            {
              day = stringToInt(field.value.substr(pos, 2));
              if (isNaN(day) || day < 1 || day > 31)
                error = 103;                               // illegal value for day
              else
                switch (month)
                {
                  case 2:
                    if (day > 29 || (year % 4 != 0 && day > 28))
                      error = 103;                         // illegal value for day
                    break;
                  case 4,6,9,11:
                    if (day > 30)
                      error = 103;                         // illegal value for day
                }
            }
          }
        }
      }
    }
  
  if (error)
  {
    show(messages[0] + nl + name + nl + messages[error] + nl + format);
    field.select();
    field.focus();
    return false;
  } else {
    if (flag)
      gotoField(next);
    return true;
  }
}

function checkList(field, name)
{
  if (field.value == '\b')
  {
    var error = 104;
    show(messages[0] + nl + name + nl + messages[error]);
    field.focus();
    return false;
  }

  return true;
}

function checkListInput(inputField, name, listField)
{
  if (listField.value != inputField.value || listField.value == '\b')
  {
    var error = 105;
    show(messages[0] + nl + name + nl + messages[error]);
    inputField.select();
    inputField.focus();
    return false;
  }

  return true;
}

function checkListOption(field, name)
{
  if (isChecked(field))
    return true;

  var error = 106;
  show(messages[0] + nl + name + nl + messages[error]);
  field[0].focus();
  
  return false;
}

function checkIntRange(field, name, obligatory, low, high, step, flag, next)
{
  var error = 0;
  var intValue, message;
  
  if (field.value == '')
    if (obligatory)
      error = 100;
    else;
  else if (!isInt(field.value))
    error = 107;
  else
  {
    intValue = parseInt(field.value);
    if ((intValue < low) || (intValue > high))
      error = 107;                                         // value out of range
    else if ((step > 1) && ((intValue - low) % step))
      error = 108;                                         // illegal step rate
  }

  if (error)
  {
    message = messages[error].replace(/#LOW/, String(low)).replace(/#HIGH/, String(high)).replace(/#STEP/, String(step));
    show(messages[0] + nl + name + nl + message);
    field.select();
    field.focus();
    return false;
  } else {
    if (flag)
      gotoField(next);
    return true;
  }
}

function checkFixedRange(field, name, obligatory, low, high, flag, next)
{
  var error = 0;
  var value = field.value.replace(/,/, '.');
  var dblValue, message;

  if (field.value == '')
    if (obligatory)
      error = 100;
    else;
  else if (isNaN(value))
    error = 109;
  else
  {
    dblValue = parseFloat(value);
    if ((dblValue < low) || (dblValue > high))
      error = 109;                                         // value out of range
  }

  if (error)
  {
    message = messages[error].replace(/#LOW/, String(low)).replace(/#HIGH/, String(high));
    show(messages[0] + nl + name + nl + message);
    field.select();
    field.focus();
    return false;
  } else {
    if (flag)
      gotoField(next);
    return true;
  }
}

function enter(type, field, next, name, param1, param2, param3, param4)
{
  var result = true;
  
  auto = false;
  document.inputForm._focusedItem.value = (type == 'olist' && field.length > 1) ? field[0].name : field.name;
  nextField = next;

  if (lastField && (field != lastField))
  {
    result = checkField(true, field);
    if (result && evalRules && (rules == 1 || (rules > 1 && document.inputForm._evalRules)) && name != lastName)
    with (document.inputForm)
    {
      field.blur();
      showOverlay();
      _actualItem.value = ((lastType == 'olist') && lastField.length && (lastField.length > 1)) ? lastField[0].name : lastField.name;
      _actionCode.value = rules << 8;
      submit();
      return;
    }
    evalRules = true;
  }

  if (result)
  {
    lastType = type;
    lastField = field;
    lastName = name;
    switch (lastType)
    {
      case 'irange':
        lastParam4 = param4;

      case 'frange':
	lastParam3 = param3;

      case 'date':   
      case 'ident':
        lastParam2 = param2;
      
      case 'list':
      case 'ilist':
      case 'upload':
        lastParam1 = param1;
    }
  }
}

function saveRequest()
{
  return confirm(messages[300]);
}

function autoSaveRequest()
{
  if (document.inputForm._confirmAutoSave)
    if (document.inputForm._changed)
      with (document.inputForm)
        if (_changed.value == 'True')
          return confirm(messages[300]);
 
  return true; 
}

function openFile(fileNo, recFilter)
{
  with (document.inputForm)
  {
    expression = /(.*\/)(\w+)($|\?)(.*)/;
    search = expression.exec(action);

    if (document.inputForm._changed)
      if (_changed.value == 'True')
      {
        if (search)
          action = search[1] + search[2] + '?file=' + fileNo + ((search[4]) ? '&' + search[4] : '')
        _actionCode.value = '7';
        submit();
        return;
      }

    lastAction = action;
    lastTarget = target;
    if (search)
      action = search[1] + 'openfile?file=' + fileNo + ((recFilter) ? '&record=' + recFilter : '') + ((search[4]) ? '&' + search[4] : '')
    target = 'Datei' + fileNo;
    try
    {
      submit();
    }
    finally
    {
      action =  lastAction;
      target = lastTarget;
    }
  }
}

function checkSaved(msgNo)
{
  if (!saved && (document.inputForm.errorCode || (document.inputForm._changed && document.inputForm._changed.value == 'True')))
    return confirm(messages[msgNo]);
  else
    return true;
}

function openHelp(helpFile)
{
  window.open(helpFile, 'Help', 'resizable=yes, scrollbars=yes, dependent=yes');
}

function showMessage(msgCode, msgText)
{
  var msgNo = stringToInt(msgCode);
  var msgStr = (msgNo < 400 ? messages[msgNo] : warnings[msgNo - 400]);
  var msgArr = new Array;
  var l = 0;
  var i = 1;
  var f = document.inputForm;

  if (msgText.length > 0)
    if (msgStr.indexOf('#PARAM') < 0)
      msgArr = msgStr.concat('' + msgText).split('');
    else
      msgArr[0] = msgStr.replace(/#PARAM/, msgText);
  else
    msgArr[0] = msgStr;
  l = msgArr.length;

  if (msgNo > 400)
  {
    var ok = true;
    
    do {
      var j = 25;

      msgStr =  msgArr[0];
      while ((i < l) && (j-- > 0))
        msgStr += nl + msgArr[i++];
      ok &= confirm(msgStr + nl + nl + warnings[0]);
    } while (ok && (i < l));
    if (ok)
    {
      if ((f._actualItem.value == '0') || (f._actionCode.value == '0'))
        setFocus(f._focusedItem.value);
      else
      {
        f._ignoreRules.value = 'True';
        showOverlay();
        f.submit();
      }
    }
    else
    {
      f._page.selectedIndex = f._actualPageNo.value;
      setFocus(f._actualItem.value);
    }
  } else {
    do {
      var j = 25;

      if (msgNo > 0 && msgNo < 200)
        msgStr = messages[0] + nl + msgArr[0];
      else
        msgStr = msgArr[0];
      while ((i < l) && (j-- > 0))
        msgStr += nl + msgArr[i++];
      show(msgStr);
    } while (i < l);
  }
}

function show(text)
{
  notified = true;
  alert(text);
}

function showMessages(msgCode, msgText)
{
  if (msgCode.length)
    for (var i=0; i<msgCode.length; i++)
      showMessage(msgCode[i].value, msgText[i].value);
  else
    showMessage(msgCode.value, msgText.value);
}

function checkMessage()
{
  if (document.inputForm._msgCode)
    showMessage(document.inputForm._msgCode.value, document.inputForm._msgText.value);
}

function openPDF()
{
  with (document.inputForm)
  {
    var lastAction = action;
    var lastTarget = target;
    action = _printScript.value;
    target = 'PDF-Print';
    try
    {
      submit();
    }
    finally
    {
      action =  lastAction;
      target = lastTarget;
    }
  }
}

function uploadImport()
{
  with (document.inputForm)
  {
    if (uploadFile.value.length)
      switch (getExtension(uploadFile.value))
      {
        case '.txt':
        case '.dat':
        case '.csv':
            lastAction = action;
            action = _uploadScript.value;
            encoding = 'multipart/form-data';
            send(4, true);
            action = lastAction;
        break;

        default:
          show(messages[113]);
      }
    else
      show(messages[112]);
  }
}

function doImport()
{
  with (document.inputForm)
  {
    if (fileList.value.length)
      send(6, true);
    else
      show(messages[112]);
  }
}

function setFocus(itemName)
{
  var item;
  var radio;
  var i;

  item = document.getElementsByName(itemName)[0];
  if (item)
  {
    if (item.type == 'radio')
    {
      i = 0;
      while (radio = document.getElementsByName(document.inputForm._focusedItem.value)[i++])
        if (radio.checked)
        {
          item = radio;
          break;
        }
    }
    item.focus();
    if (item.type == 'text' || item.type == 'textarea')
      item.select();
  }
}

function showOverlay()
{
  overlay = document.createElement("div");
  overlay.setAttribute("id", "overlay");
  if ((navigator.appName == 'Microsoft Internet Explorer') && !document.compatMode.match(/^CSS/i))
    overlay.style.position = "absolute";
  document.body.appendChild(overlay);
  loaderPic = document.getElementById("loader");
  if (loaderPic)
  {
    if ((navigator.appName == 'Microsoft Internet Explorer') && !document.compatMode.match(/^CSS/i))
      loaderPic.style.position = "absolute";
    loaderPic.style.display = "inline";
  }
}

function logoff()
{
  with (document.inputForm)
  {
    expression = /(.*\/)(\w+)($|\?.*)/;
    if (search = expression.exec(action))
      action = search[1] + 'logoff' + search[3];
    send(99, true);
  }
}

function closeWindow()
{
  with (document.inputForm)
  {
    expression = /(.*\/)(\w+)($|\?.*)/;
    if (search = expression.exec(action))
      action = search[1] + 'close' + search[3];
    submit();
  }
}

function impFileChange()
{
  with (document.inputForm)
  {
    if (fileList.value.substr(-3).toLowerCase() == 'csv')
    {
      fileFmt[1].checked = true;
      setImpState('csv');
    } else { 
      fileFmt[0].checked = true;
      setImpState('fixed');
    }
  }
}

function setImpState(mode)
{
  with (document.inputForm)
  {
    if (mode == 'fixed')
    {
      fieldSep.disabled = true;
      stringDel.disabled = true;
      sepChar.disabled = true;
      delChar.disabled = true;
    } else { 
      fieldSep.disabled = false;
      stringDel.disabled = false;
      sepChar.disabled = false;
      delChar.disabled = false;
    }
  }
}

function showTemplate()
{
  with (document.inputForm)
  {
    var lastAction = action;
    expression = /(.*\/import)($|\?.*)/;
    if (search = expression.exec(action))
      action = search[1] + (fileFmt[0].checked ? '.dat' : '.csv') + search[2];
    _actionCode.value = 7;
    try
    {
      submit();
    }
    finally
    {
      action =  lastAction;
    }
  }
}

function gotoField(target)
{
  if (target) 
    setFocus(target.name);
  else if (autoPaging)
    nextPage();
}

function checkUpload(field, name, obligatory)
{
  if (obligatory && field.value == '')
  {
    var error = 100;
    show(messages[0] + nl + name + nl + messages[error]);
    field.select();
    field.focus();
    return false;
  }
  
  return true;

}

function uploadFiles()
{
  with (inputForm)
  {
    var lastAction = action;
    var lastEncoding = encoding;
    var lastTarget = target;
    action = document.inputForm._uploadScript.value;
    encoding = 'multipart/form-data';
    target = '_blank';
    method = 'POST';
    try
    {
      submit();
    }
    finally
    {
      action =  lastAction;
      encoding = lastEncoding;
      target = lastTarget;
    }
  }
}

function searchInputChanged(inputField, listField, length)
{
  if (inputField.value.length == length)
  {
    listField.value = inputField.value;
    if (listField.value != inputField.value)
    {
      listField.value = '';
      show(messages[0] + nl + messages[105]);
      inputField.value = inputField.value.substr(0, length-1);
    }
  }
}

function nextPage()
{
  if (checkValues())
    send(5, true);
}

function defined(variable)
{
  return typeof variable != "undefined"
}

function send(code, hide, auto)
{
  var f = document.inputForm;

  f._actionCode.value = code
  f.target = '';
  if (!auto)
    f.submit();
  if (hide) 
    showOverlay();
}

function checkTAN(input, button)
{
  button.disabled = !(input.value.length == input.maxLength);
}

function checkField(allowEmpty, field)
{
  if (lastField)
  {
    switch (lastType)
    {
      case 'ident':
        return checkIdent(lastField, lastName, lastParam1, lastParam2);

      case 'date':
        return checkDate(lastField, lastName, lastParam1, lastParam2);

      case 'list':
        if (allowEmpty && listEmpty(lastField.options))
          return true;
        else
          return checkList(lastField, lastName);

      case 'ilist': 
        if (field && (lastParam1 != field))
          return checkListInput(lastField, lastName, lastParam1);
        else
          return true;

      case 'olist':
        return checkListOption(lastField, lastName);

      case 'irange':
        return checkIntRange(lastField, lastName, lastParam4, lastParam1, lastParam2, lastParam3);

      case 'frange':
        return checkFixedRange(lastField, lastName, lastParam3, lastParam1, lastParam2);

      case 'upload':
        return checkUpload(lastField, lastName, lastParam1);

      default:
        return true;
    }
  }
  else
    return true;
}

function enterLink(obj, src)
{
  $("body").css("cursor","pointer");
  if (src)
  {
    var img = $(obj).find("img")[0];
    img.src = src;
  }
  $(obj).find(".cssLink").addClass("cssHover");
}

function exitLink(obj, src)
{
  if (src)
  {
    var img = $(obj).find("img")[0];
    img.src = src;
  }
  $(obj).find(".cssHover").removeClass("cssHover");
  $("body").css("cursor","auto");
}

function changeList(list)
{
  document.inputForm._changed.value = 'True';
  if ((list.value != '\b') && list.options[0] && (list.options[0].value == '\b'))
    list.remove(0);
}

function propagate(field)
{
  propagating[field.name] = true;
  field.onchange();
  propagating[field.name] = false;
}

function propagateUp(table, parent, child)
{
  var name = (parent.type == undefined) ? parent[0].name : parent.name;

  if (!propagating[name])
  {
    var val = table[child.value];

    switch (parent[0].type)
    {
      case 'radio':
        for (var i=0; i<parent.length; i++)
          if (parent[i].value == val)
          {
            parent[i].checked = true;
            propagate(parent[i]);
          }
      break;
      case 'text':
        parent[1].value = val;
        propagate(parent[1]);
      break;
      default:
        parent.value = val;
        propagate(parent);
    }
    return true;
 }
 else
   return false;
}

function propagateDown(table, parent, child)
{
  var index = 0;
  var name = (child.type == undefined) ? child[0].name : child.name;
  var val = ((parent.type == 'radio') && !parent.checked) ? '' : parent.value;
    
  propagating[parent.name] = true;
  if (child[0].type == 'radio')
  {
    if (val == '')
      for (var i=0; i<child.length; i++)
      {
        child[i].checked = false;
        child[i].disabled = false;
      }
    else
      for (var i=0; i<child.length; i++)
        if (table[child[i].value] != val)
        {
          child[i].disabled = true;
          child[i].checked = false;
        }
        else
        {
          child[i].disabled = false;
          if (child[i].checked)
            index = i;
        }
    child[index].onchange();
  } else {
    var list = (child[0].type == 'text') ? child[1] : child;

    if (val == '')
      for (var i=0; i<list.length; i++)
      {
        list.options[i].disabled = false;
        list.options[i].style.display = '';
      }
    else
      for (var i=0; i<list.length; i++)
        if ((list.options[i].value != '\b') && (table[list.options[i].value] != val))
        {
          list.options[i].disabled = true;
          list.options[i].style.display = 'none';
        } else {
          list.options[i].disabled = false;
          list.options[i].style.display = '';
        }
    if (table[list.value] != val)
    {
      if (list.options[0].value != '\b')
        $(list).prepend('<option value="\b">&nbsp;</option>');
      list.value = '\b';
    }
    list.onchange();
  }
  propagating[parent.name] = false;
}

function reduce(table, field, val)
{
  switch (field[0].type)
  {
    case 'radio':
      for (var i=0; i<field.length; i++)
          if (table[field[i].value] != val)
            field[i].disabled = true;
          else
            field[i].disabled = false;
    break;
    case 'text':
      for (var i=0; i<field[1].length; i++)
        if ((field[1].options[i].value != '\b') && (table[field[1].options[i].value] != val))
        {
          field[1].options[i].disabled = true;
          field[1].options[i].style.display = 'none';
        } else {
          field[1].options[i].disabled = false;
          field[1].options[i].style.display = '';
        }
    break;
    default:
      for (var i=0; i<field.length; i++)
        if (table[field.options[i].value] != val)
        {
          field.options[i].disabled = true;
          field.options[i].style.display = 'none';
        } else {
          field.options[i].disabled = false;
          field.options[i].style.display = '';
        }
  }
}

function listEmpty(list)
{
  if (list[0].value != '\b')
    return false;
  else
    for (var i=1; i<list.length; i++)
      if (!list[i].disabled)
        return false;
  
  return true;
}

function setCursor(shape)
{
  document.body.style.cursor = shape;
}